@@ -87,7 +87,7 @@ class RobotJiminyEnv(gym.core.Env):
         ## Set the metadata of the environment. Those information are
         #  used by some gym wrappers such as VideoRecorder.
         self.metadata = {
-            'render.modes': ['human', 'rgb_array', 'depth_array'],
+            'render.modes': ['human', 'rgb_array'],
             'video.frames_per_second': int(np.round(1.0 / self.dt))
         }
 
@@ -578,8 +578,10 @@ class RobotJiminyEnv(gym.core.Env):
             log_data = self._log_data
         else:
             log_data, _ = self.engine.get_log()
-        self.engine_py._viewer = play_logfiles([self.robot], [log_data],
-            viewers=[self.engine_py._viewer], close_backend=False, **kwargs)[0]
+        self.engine_py._viewer = play_logfiles(
+            [self.robot], [log_data], viewers=[self.engine_py._viewer],
+            close_backend=False, verbose=True, **kwargs
+        )[0]
 
     def close(self):
         """
